@@ -1,7 +1,8 @@
 """Utility functions for working with Wikidata"""
 import requests
+import re
 
-__version__ = '0.3'
+__version__ = '0.5'
 
 
 def get_coordinates_from_wd_point(point_str):
@@ -20,7 +21,7 @@ def get_wd_id_from_url(url):
     return match.groups()[0]
 
 
-def run_query(query):
+def run_wikidata_query(query):
 
     url = 'https://query.wikidata.org/sparql'
 
